Module varnish — Inmanta 2017.4dev documentation

# Module varnish

> - License: Apache 2.0
> - Version: 0.1
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/varnish.git

## Entities

entity `varnish::Proxy`

  Parents: `web::HostedLoadBalancer`

  The following implements statements select implementations for this entity:

  > - `varnish::varnishProxy`

## Implementations

implementation `varnish::varnishProxy`

## Plugins

`varnish.` `escape`(name: string) → string

  Escape all dots. This can be used to use a domain name in a regular expression

  Parameters: | name – The hostname to escape

`varnish.` `var`(name: string) → string

  Plugin that replaces characters that are not allowed in varnish identifiers

  Parameters: | name – The identifier to clean up